from activity.run_model import *
from activity.osmotic import *
from activity.density_script import *

class Solution:
    def activity_coefficient (df, target_ion, T = 298.15):
        return pitzer_activity_coefficient(df, target_ion, T)

    def osmotic_coefficient_ (df, T = 298.15):
        return osmotic_coefficient(df, T)
    
    def ionic_strength_(df, T = 298.15):
        density_ = density(df, T)
        molality = [x * (1/density_) for x in df['Concentration (mol/L)']]
        
        d = {'Component' : df['Component'],
            'Molality' : molality,
            'Charge' : df['Charge']
            }
        
        return ionic_strength(pd.DataFrame(data = d))
    
    def density_(df, T = 298.15):
        rho = density(df, T)
        return rho
    
    def activity_water(df, T = 298.15):
        return activity_h2o(df, T)
    
    def notable_constants(df, T = 298.15):
        #constant "A^(phi)"
        A_ = A_calc(T)
        
        density_ = density(df, T)
        molality = [x * (1/density_) for x in df['Concentration (mol/L)']]
        d = {'Component' : df['Component'],
            'Molality' : molality,
            'Charge' : df['Charge']
            }
        
        df_prime = pd.DataFrame(data = d) #df with molality instead of concentration
        
        #constant F
        F_ = F_calc(df_prime, A_)
        
        #dielectric constant
        epsilon = dielectric_constant(T)
        
        return A_, F_, epsilon


from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

#with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
#    long_description = "\n" + fh.read()

VERSION = '0.0.2.1.2'
DESCRIPTION = 'Computes details of solution for modeling purposes'
LONG_DESCRIPTION = """
A package that was created for the purpose of process modeling in different membranes. This is a solution chemistry toolkit
that can compute details of "saline" solutions such as the activity coefficient of each ion (using the Pitzer model),
osmotic coefficient, ionic strength, density of the solution, etc.
"""

# Setting up
setup(
    name="pySolution",
    version=VERSION,
    author="Sartaaj Khan",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=['numpy', 'pandas', 'scipy', 'joblib', 'proplot', 'matplotlib'],
    keywords=['python', 'solution chemistry', 'activity coefficient', 'osmosis', 'reverse osmosis', 'chemistry'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)